import { basicSetup } from 'codemirror';
import { EditorView, keymap } from '@codemirror/view';
import { javascript } from '@codemirror/lang-javascript';
import { vscodeKeymap } from '@replit/codemirror-vscode-keymap';
import { Compartment, Prec } from '@codemirror/state';
import { deleteLine } from '@codemirror/commands';
import { vscodeLight } from '@uiw/codemirror-theme-vscode';

export * as codemirror from 'codemirror';
export * as view from '@codemirror/view';
export * as langJavascript from '@codemirror/lang-javascript';
export { vscodeKeymap } from '@replit/codemirror-vscode-keymap';
export * as state from '@codemirror/state';
export * as commands from '@codemirror/commands';
export * as vscodeTheme from '@uiw/codemirror-theme-vscode';
export * as autocomplete from '@codemirror/autocomplete';
export * as collab from '@codemirror/collab';
export * as language from '@codemirror/language';
export * as lint from '@codemirror/lint';
export * as search from '@codemirror/search';

export function generateBasicExtensions() {
  const themeConfig = new Compartment();
  return {
    themeConfig: themeConfig,
    extensions: [
      basicSetup,
      Prec.high(keymap.of([{ key: 'Mod-d', run: deleteLine }])),
      keymap.of(vscodeKeymap),
      themeConfig.of([vscodeLight]),
    ],
  };
}

export function generateJavascriptExtensions() {
  const { themeConfig, extensions } = generateBasicExtensions();
  return {
    themeConfig: themeConfig,
    extensions: [...extensions, javascript()],
  };
}

export default function defaultEditor({ parent, doc } = { parent: document.body, doc: '' }) {
  const { themeConfig, extensions } = generateJavascriptExtensions();

  const editor = new EditorView({
    doc: doc,
    extensions: [...extensions],
    parent: parent,
  });

  return { themeConfig: themeConfig, editor: editor };
}
export { defaultEditor };
